@@ -2,6 +2,8 @@ import discord
 import asyncio
 from discord.ext import commands
 
+__all__ = ["AutoEmbedPaginator", "CustomEmbedPaginator"]
+
 class AutoEmbedPaginator(object):
     def __init__(self, ctx, **kwargs):
         self.embeds = None
@@ -9,27 +11,32 @@ class AutoEmbedPaginator(object):
         self.bot = ctx.bot
         self.current_page = 0
         self.auto_footer = kwargs.get("auto_footer", False)
-        self.remove_reactions = kwargs.get("remove_reactions", True)
+        self.remove_reactions = kwargs.get("remove_reactions", False)
         self.control_emojis = ('⏮️', '⏪', '🔐', '⏩', '⏭️')
         self.timeout = int(kwargs.get("timeout", 60))
-    async def run(self, embeds):
+    async def run(self, embeds, send_to=None):
+        if not send_to:
+        	send_to = self.ctx
+        wait_for = self.ctx.author if send_to == self.ctx else send_to
         if not self.embeds:
             self.embeds = embeds
         if self.auto_footer:
             self.embeds[0].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
-        msg = await self.ctx.send(embed=self.embeds[0])
+        msg = await send_to.send(embed=self.embeds[0])
         for emoji in self.control_emojis:
             await msg.add_reaction(emoji)
         msg = await msg.channel.fetch_message(msg.id)
         def check(reaction, user):
-            return user == self.ctx.author and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
+            return user == wait_for and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
         while True:
             if self.timeout > 0:
                 try:
                     reaction, user = await self.bot.wait_for("reaction_add",check=check, timeout=self.timeout)
                 except asyncio.TimeoutError:
                     self.current_page = 0
-                    await msg.clear_reactions()
+                    for reaction in msg.reactions:
+                        if reaction.message.author.id == self.bot.user.id:
+                            await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
                     return
                     break
             else:
@@ -107,23 +114,27 @@ class CustomEmbedPaginator(object):
     def clear_reactions(self):
         self.control_emojis = []
         self.control_commands = []
-    async def run(self, embeds):
-        self.update_called = False
+    async def run(self, embeds, send_to=None):
         self.embeds = embeds
+        if not send_to:
+        	send_to = self.ctx
+        wait_for = ctx.author if send_to == self.ctx else send_to
         if self.auto_footer:
             self.embeds[0].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
-        msg = await self.ctx.send(embed=self.embeds[0])
+        msg = await send_to.send(embed=self.embeds[0])
         for emoji in self.control_emojis:
             await msg.add_reaction(emoji)
         msg = await msg.channel.fetch_message(msg.id)
         def check(reaction, user):
-            return user == self.ctx.author and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
+            return user == wait_for and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
         while True:
             if self.timeout > 0:
                 try:
                     reaction, user = await self.bot.wait_for("reaction_add",check=check, timeout=self.timeout)
                 except asyncio.TimeoutError:
-                    await msg.clear_reactions()
+                    for reaction in msg.reactions:
+                        if reaction.message.author.id == self.bot.user.id:
+                            await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
                     self.current_page = 0
                     return
                     break
